# MDRMF
Multiple drug resistance machine fishing
- A project to explore ML models using active pool-based learning (machine fishing) for transporters implicated in MDR.

# Installation
python -m pip install MDRMF
[MDRMF](https://pypi.org/project/MDRMF/)